@@ -4,14 +4,14 @@ from subprocess import PIPE, Popen
 class bash(object):
     "This is lower class because it is intended to be used as a method."
 
-    def __init__(self, cmd, env=None):
+    def __init__(self, *args, **kwargs):
         self.p = None
         self.stdout = None
-        self.bash(cmd, env)
+        self.bash(*args, **kwargs)
 
-    def bash(self, cmd, env=None):
+    def bash(self, cmd, env=None, stdout=PIPE):
         self.p = Popen(
-            cmd, shell=True, stdout=PIPE, stdin=PIPE, stderr=PIPE, env=env
+            cmd, shell=True, stdout=stdout, stdin=PIPE, stderr=PIPE, env=env
         )
         self.stdout, self.stderr = self.p.communicate(input=self.stdout)
         self.code = self.p.returncode
